# pypi-workflow

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![GitHub License](https://img.shields.io/github/license/SpaceShaman/pypi-workflow)
![Tests](https://img.shields.io/github/actions/workflow/status/SpaceShaman/pypi-workflow/tests.yml?label=tests)
![Codecov](https://img.shields.io/codecov/c/github/SpaceShaman/pypi-workflow)
